@@ -16,9 +16,9 @@ use HTTP::Request;
 sub prep001_messenger_available : Test(startup => 2) {
     my $self = shift;
     use_ok('WebService::Raygun::Messenger')
-      or $self->FAIL_ALL('Messenger class not available.');
+        or $self->FAIL_ALL('Messenger class not available.');
     use_ok('WebService::Raygun::Message')
-      or $self->FAIL_ALL('Message class not available.');
+        or $self->FAIL_ALL('Message class not available.');
 
 }
 
@@ -26,34 +26,48 @@ sub t0010_raygun_http_403_response : Test(2) {
     my $self      = shift;
     my $messenger = WebService::Raygun::Messenger->new(
         api_key => '',
-        message => test_message()
-    );
+        message => test_message());
     my $result;
     lives_ok {
         $result = $messenger->fire_raygun();
     }
     'Called Raygun.io';
-    cmp_ok( $result->code, '==', 403, 'Expect a "Bad Request" error.' );
+    cmp_ok($result->code, '==', 403, 'Expect a "Bad Request" error.');
 }
 
 sub t0020_raygun_http_ok_response : Test(2) {
     my $self    = shift;
     my $api_key = $ENV{RAYGUN_API_KEY};
-    if ( not defined $api_key ) {
+    if (not defined $api_key) {
         $self->SKIP_ALL('No API key for Raygun.io. No point in continuing.');
     }
     $self->{api_key} = $api_key;
     my $messenger = WebService::Raygun::Messenger->new(
         api_key => $self->{api_key},
-        message => test_message()
-    );
+        message => test_message());
     my $result;
     lives_ok {
         $result = $messenger->fire_raygun;
     }
     'Called Raygun.io';
 
-    cmp_ok( $result->code, '<', 400, 'Expect a "Bad Request" error.' );
+    cmp_ok($result->code, '<', 400, 'Expect a "Bad Request" error.');
+}
+
+sub t0030_init_with_string_as_message : Test(1) {
+    my $self = shift;
+
+    my $messenger;
+    lives_ok {
+        $messenger = WebService::Raygun::Messenger->new(
+            api_key => 'wMqgsBks1FfJihdrA2Aydg==',
+            message => {
+                user  => 'null@null.com',
+                error => "string whatever",
+            });
+    }
+    'No problem instantiating a messenger';
+
 }
 
 sub test_message {
